@@ -82,6 +82,12 @@ a connected broker implies is attached to cores or cores could reach out to comm
 return 0 if not connected , something else if it is connected*/
 HELICS_EXPORT int helicsBrokerIsConnected (helics_broker broker);
 
+/** wait for the broker to disconnect
+@param broker the broker to wait for
+@param msToWait the time out in millisecond (<0 for infinite timeout)
+*/
+HELICS_EXPORT helics_status helicsBrokerWaitForDisconnect (helics_broker broker, int msToWait);
+
 /** check if a core is connected
 a connected core implies is attached to federate or federates could be attached to it
 return 0 if not connected , something else if it is connected*/
@@ -138,6 +144,15 @@ HELICS_EXPORT helics_federate helicsGetFederateByName (const char *fedName);
 */
 HELICS_EXPORT helics_status helicsBrokerDisconnect (helics_broker broker);
 
+/** disconnect and free a broker*/
+HELICS_EXPORT void helicsDestroyFederate (helics_federate fed);
+
+/** disconnect and free a broker*/
+HELICS_EXPORT void helicsDestroyBroker (helics_broker broker);
+
+/** disconnect and free a core*/
+HELICS_EXPORT void helicsDestroyCore (helics_core core);
+
 /** release the memory associated with a core*/
 HELICS_EXPORT void helicsCoreFree (helics_core core);
 /** release the memory associated with a broker*/
@@ -156,7 +171,7 @@ HELICS_EXPORT helics_federate helicsCreateValueFederate (const helics_federate_i
 @param JSON  a JSON file or a JSON string that contains setup and configuration information
 @return an opaque value federate object
 */
-HELICS_EXPORT helics_federate helicsCreateValueFederateFromJson (const char *json);
+HELICS_EXPORT helics_federate helicsCreateValueFederateFromJson (const char *JSON);
 
 /** create a message federate from a federate info object
 @details helics_message_federate objects can be used in all functions that take a helics_message_federate or helics_federate object as an
@@ -172,7 +187,7 @@ argument
 @param JSON  a JSON file or a JSON string that contains setup and configuration information
 @return an opaque message federate object
 */
-HELICS_EXPORT helics_federate helicsCreateMessageFederateFromJson (const char *json);
+HELICS_EXPORT helics_federate helicsCreateMessageFederateFromJson (const char *JSON);
 
 /** create a combination federate from a federate info object
 @details combination federates are both value federates and message federates, objects can be used in all functions that take a
@@ -188,7 +203,7 @@ helics_federate, helics_message_federate or helics_federate object as an argumen
 @param JSON  a JSON file or a JSON string that contains setup and configuration information
 @return an opaque combination federate object
 */
-HELICS_EXPORT helics_federate helicsCreateCombinationFederateFromJson (const char *json);
+HELICS_EXPORT helics_federate helicsCreateCombinationFederateFromJson (const char *JSON);
 
 /** create a new reference to an existing federate
 @details this will create a new helics_federate object that references the existing federate it must be freed as well
